@@ -1,5 +1,5 @@
 package Beam::Minion::Command::job;
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 # ABSTRACT: Command to manage minion jobs
 
 #pod =head1 SYNOPSIS
@@ -83,10 +83,10 @@ use Beam::Minion::Util qw( build_mojo_app );
 use Minion::Command::minion::job;
 
 sub run {
-    my ( $class ) = @_;
+    my ( $class, @args ) = @_;
     my $app = build_mojo_app();
     my $cmd = Minion::Command::minion::job->new( app => $app );
-    $cmd->run;
+    $cmd->run( @args );
 }
 
 1;
@@ -101,7 +101,7 @@ Beam::Minion::Command::job - Command to manage minion jobs
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
