@@ -1,5 +1,5 @@
 package Beam::Minion::Command::worker;
-our $VERSION = '0.009';
+our $VERSION = '0.010';
 # ABSTRACT: Command to run a Beam::Minion worker
 
 #pod =head1 SYNOPSIS
@@ -42,10 +42,10 @@ use Beam::Minion::Util qw( build_mojo_app );
 use Minion::Command::minion::worker;
 
 sub run {
-    my ( $class ) = @_;
+    my ( $class, @args ) = @_;
     my $app = build_mojo_app();
     my $cmd = Minion::Command::minion::worker->new( app => $app );
-    $cmd->run;
+    $cmd->run( @args );
 }
 
 1;
@@ -60,7 +60,7 @@ Beam::Minion::Command::worker - Command to run a Beam::Minion worker
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 SYNOPSIS
 
